/**
 * Service which exposes the supported external logins.
 */
angular.module('quay').factory('ExternalLoginService', ['Features', 'Config',
  function(Features, Config) {
  var externalLoginService = {};

  externalLoginService.EXTERNAL_LOGINS = window.__external_login;

  externalLoginService.getLoginUrl = function(loginService, action) {
    var loginUrl = loginService['config']['AUTHORIZE_ENDPOINT'];
    var clientId = loginService['config']['CLIENT_ID'];

    var scope = loginService.scopes.join(' ');
    var redirectUri = Config.getUrl('/oauth2/' + loginService['id'] + '/callback');

    if (action == 'attach') {
      redirectUri += '/attach';
    }

    var url = loginUrl + 'client_id=' + clientId + '&scope=' + scope + '&redirect_uri=' +
              redirectUri;
    return url;
  };

  externalLoginService.hasSingleSignin = function() {
    return externalLoginService.EXTERNAL_LOGINS.length == 1 && !Features.DIRECT_LOGIN;
  };

  externalLoginService.getSingleSigninUrl = function() {
    // If there is a single external login service and direct login is disabled,
    // then redirect to the external login directly.
    if (externalLoginService.hasSingleSignin()) {
      return externalLoginService.getLoginUrl(externalLoginService.EXTERNAL_LOGINS[0]);
    }

    return null;
  };

  return externalLoginService;
}]);